@@ -125,10 +125,10 @@ def get_xye(argfiles, label, romin=0, romax=10000):
     return data, names
 
 
-if __name__ == '__main__':
+def main():
     t0 = time()
 
-    parser = argparse.ArgumentParser(description='At least better than plotdata')
+    parser = argparse.ArgumentParser(description='Quick file-based plotting for Linux and Windows')
     parser.add_argument('datafiles', nargs='+', type=str,
                         help='String(s) passed to glob to look for plottable files')
     parser.add_argument('-l','--label', choices=['index','prefix','dir','full'],
@@ -183,3 +183,5 @@ if __name__ == '__main__':
     if (sys.flags.interactive != 1) or not hasattr(QtCore, 'PYQT_VERSION'):
         pg.mkQApp().instance().exec_()
 
+if __name__ == '__main__':
+    main()
\ No newline at end of file
